@@ -1,4 +1,4 @@
-from src.kiwi import KiwiCoder
+from kiwi import KiwiCoder
 
 
 # def test_app_config():
